**To delete a wireless device**

The following ``delete-wireless-device`` example deletes a wireless device that has the specified ID. ::

    aws iotwireless delete-wireless-device \
        --id "12345678-a1b2-3c45-67d8-e90fa1b2c34d"

This command produces no output.

For more information, see `Connecting devices and gateways to AWS IoT Core for LoRaWAN <https://docs.aws.amazon.com/iot/latest/developerguide/connect-iot-lorawan.html>`__ in the *AWS IoT Developers Guide*.
